@@ -122,6 +122,10 @@ def _read_segments(root: ET.Element):
             segments.append(_read_intersection_element(segment_element))
         elif segment_element.tag == 'Gap':
             segments.append(_read_gap_element(segment_element))
+        elif segment_element.tag == 'ParkingArea':
+            segments.append(_read_parking_area_element(segment_element))
+        elif segment_element.tag == 'TrafficIsland':
+            segments.append(_read_traffic_island_element(segment_element))
 
     return segments
 
@@ -168,11 +172,20 @@ def _read_turn_element(turn_element: ET.Element):
 
 
 def _read_crosswalk_element(crosswalk_element: ET.Element):
-    return Crosswalk()
+    length = crosswalk_element.get('length')
+
+    if length is None:
+        raise AttributeMissingException('length', crosswalk_element)
+
+    return Crosswalk(float(length))
 
 
 def _read_intersection_element(intersection_element: ET.Element):
-    return Intersection()
+    length = intersection_element.get('length')
+
+    if length is None:
+        raise AttributeMissingException('length', intersection_element)
+    return Intersection(float(length))
 
 
 def _read_gap_element(straight_element: ET.Element):
@@ -182,3 +195,53 @@ def _read_gap_element(straight_element: ET.Element):
         raise AttributeMissingException('length', straight_element)
 
     return Gap(float(length))
+
+
+def _read_spot_element(spot_element: ET.Element) -> ParkingArea.ParkingLot.Spot:
+    type = spot_element.get('type')
+    length = spot_element.get('length')
+    return ParkingArea.ParkingLot.Spot(type, float(length))
+
+
+def _read_parking_lot_element(parking_lot_element: ET.Element) -> ParkingArea.ParkingLot:
+    start = parking_lot_element.get('start')
+    depth = parking_lot_element.get('depth')
+    opening_ending_angle = parking_lot_element.get('opening_ending_angle')
+    spots: List[ParkingArea.ParkingLot.Spot] = []
+
+    for spot_element in parking_lot_element:
+        spot = _read_spot_element(spot_element)
+        spots.append(spot)
+
+    return ParkingArea.ParkingLot(float(start), float(depth), float(opening_ending_angle), spots)
+
+
+def _read_parking_area_element(parking_area_element: ET.Element):
+    length = parking_area_element.get('length')
+
+    if length is None:
+        raise AttributeMissingException('length', parking_area_element)
+
+    right_lots: List[ParkingArea.ParkingLot] = []
+    left_lots: List[ParkingArea.ParkingLot] = []
+
+    right_lots_element = parking_area_element.find("RightLots")
+    for parking_lot_element in right_lots_element:
+        parking_lot = _read_parking_lot_element(parking_lot_element)
+        right_lots.append(parking_lot)
+
+    left_lots_element = parking_area_element.find("LeftLots")
+    for parking_lot_element in left_lots_element:
+        parking_lot = _read_parking_lot_element(parking_lot_element)
+        left_lots.append(parking_lot)
+
+    return ParkingArea(float(length), right_lots, left_lots)
+
+
+def _read_traffic_island_element(traffic_island_element: ET.Element):
+    island_width = traffic_island_element.get('island_width')
+    crosswalk_length = traffic_island_element.get('crosswalk_length')
+    curve_segment_length = traffic_island_element.get('curve_segment_length')
+    curvature = traffic_island_element.get('curvature')
+
+    return TrafficIsland(float(island_width), float(crosswalk_length), float(curve_segment_length), float(curvature))
